# CHANGELOG


## v1.0.0 (2024-12-22)

### Bug Fixes

- Image created with wikilinks that don't end with image format
  ([`edd395a`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/edd395afe84e2c56f275fe3543cc2f63ed3ea4f8))

- Index file not found
  ([`585d4f8`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/585d4f80c5a0fc79a5e3784b693d3a6fc6851d91))

- Relative file not found
  ([`1a03bfa`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/1a03bfa3db016eb18acc4c710a2bf0682ae1a01e))

- Relative file not found
  ([`11ff9b2`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/11ff9b2468004876ca20cbec688843c0d0d8e1b5))

- Remove uncessary logging message
  ([`9c702a8`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/9c702a849ef577ee8dad766b04355ae95e41310c))

- Update for mkdocs 1.4.0
  ([`dc1741f`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/dc1741fb1601a181edfe072bb3feadbefe09558a))

- Update to mkdocs 1.3.0
  ([`86d8313`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/86d83132d8c3967e2fa7f89df7647d5393695648))

- Update to mkdocs 1.3.0
  ([`6529730`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/652973032718f9f2f49c837461762d4c1a88fe8e))

- **deprecation**: Remove warning_filter
  ([`380116f`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/380116f20898b64bf75b00110e8d61d05aeabc34))

fix #1

- **Wikilinks**: Removing slug in wiki seems to repear my links problem
  ([`9c3665c`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/9c3665c6657f6956f06668bde131c4ee8320272f))

### Code Style

- Ruff
  ([`7ce04e4`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/7ce04e49126e65cb3658f932d637a000d781a850))

- **black**: Using black is good for reading
  ([`46c6519`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/46c6519961bffa703990679eb5eff799f3315931))

### Continuous Integration

- Add build process
  ([`6ccda15`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/6ccda15a559ad4ab37407a2f82c9a6eccafefff0))

- Add semantic workflow
  ([`44aeb20`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/44aeb2024f9ddaa46a0c463166a806b126b63817))

- Add watchdog to see change without reloading mkdocs
  ([`6bede71`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/6bede712706bac170f6222ddf99694fabca611e8))

- Build for fork
  ([`1f74ae2`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/1f74ae20c964caea7b0b01eabe64027153c08e0b))

- Change semantic_release configuration
  ([`12a9508`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/12a95083b05915ff7b47348a013a0df5a3f40700))

- Do not rerun the watchdog when changed, only watch file in mkdocs_obsidian_links
  ([`53960eb`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/53960ebf6a1cec0a1a1eab874083a63e5009c271))

- Edit path for watch dog
  ([`8d70f91`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/8d70f910dc10adf72d997f6c5c1d31c6bb4dc20f))

- Set version with semantic release
  ([`f5426d0`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/f5426d0111de5111a5973f15636f80f5fc38805c))

- Strict requirements
  ([`723e7d4`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/723e7d441ffb40ac9d5c58182ee8097231eb420c))

- Update requirements & build
  ([`e5c9920`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/e5c992034849b63e67ac0c9f11db8a7627b2ba7c))

- Use poetry for managing dep and installation
  ([`9d38340`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/9d38340234126f4cefb2adb1c7860609d2582fb3))

### Features

- Rebrand
  ([`6d0c6bf`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/6d0c6bf9bd3015fc64af2faad3619d973b12bff8))

- Support for broken links
  ([`09a58ef`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/09a58ef2864e5b9181c523e255306cb7e928ca5b))

### Testing

- Add webp file to test webp
  ([`141cfe3`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/141cfe39a00386299cd3461bc731210737980bca))

- Adding index testing
  ([`48d025c`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/48d025cec40ad27e37bae72f21bdae4878bf0874))

- Update files
  ([`8722d9e`](https://github.com/Mara-Li/mkdocs-obsidian-links/commit/8722d9e59dd6d33fa9e34bc292df02e7432ab8c6))
